;;;
;;; let-opt.scm - parsing optional arguments
;;;  The definition is moved to gauche.procedure.   This file is for
;;;  backward compatibility.
;;;

(define-module gauche.let-opt
  (extend gauche.procedure))

(warn "gauche.let-opt is obsoleted.  You don't need to use it anymore.  The functionality is supported in the core.")
